module Main(main) where

import Graphics.Gloss
import Graphics.Gloss.Data.ViewPort (ViewPort)
import Data.Time.Clock.POSIX (getPOSIXTime)
import Graphics.Gloss.Interface.IO.Simulate (simulateIO)

window :: Display
window = InWindow "Ticky Tock" (400, 400) (10, 10)

background :: Color
background = white

clockOuter :: Picture
clockOuter = ThickCircle 400 5

--             LEFT/RIGHT  UP/DOWN
number12 :: Picture
number12 = Translate (-30) 330 (Scale 0.5 0.5 (Text "12"))

number1 :: Picture
number1 = Translate (180) (268) (Scale 0.5 0.5 (Text "1"))

number2 :: Picture
number2 = Translate (290) (150) (Scale 0.5 0.5 (Text "2"))

number3 :: Picture
number3 = Translate (320) (-10) (Scale 0.5 0.5 (Text "3"))

number11 :: Picture
number11 = Translate (-234) (268) (Scale 0.5 0.5 (Text "11"))

number10 :: Picture
number10 = Translate (-315) (150) (Scale 0.5 0.5 (Text "10"))

number9 :: Picture
number9 = Translate (-360) (-10) (Scale 0.5 0.5 (Text "9"))

number4 :: Picture
number4 = Translate (290) (-200) (Scale 0.5 0.5 (Text "4"))

number5 :: Picture
number5 = Translate (180) (-320) (Scale 0.5 0.5 (Text "5"))

number6 :: Picture
number6 = Translate (-8) (-368) (Scale 0.5 0.5 (Text "6"))

number7 :: Picture
number7 = Translate (-204) (-320) (Scale 0.5 0.5 (Text "7"))

number8 :: Picture
number8 = Translate (-315) (-200) (Scale 0.5 0.5 (Text "8"))

-- Function to create a clock hand
clockHand :: Float -> Float -> Picture
clockHand length angle = Line [(0, 0), (length * cos angle, length * sin angle)]

-- Function to draw clock hands for seconds, minutes, and hours
drawClockHands :: Float -> Float -> Float -> Picture
drawClockHands seconds minutes hours =
  Pictures
    [ color red $ clockHand 250 (pi / 2 - secondsAngle)   -- seconds hand
    , color blue $ clockHand 200 (pi / 2 - minutesAngle)   -- minutes hand
    , color green $ clockHand 150 (pi / 2 - hoursAngle)    -- hours hand
    ]
  where
    secondsAngle = seconds * (2 * pi / 60)
    minutesAngle = minutes * (2 * pi / 60)
    hoursAngle = (hours * 60 + minutes) * (2 * pi / 720)  -- Adjust for hour hand

-- Function to update the clock hands based on the current time
updateClockHands :: ViewPort -> Float -> (Float, Float, Float) -> IO (Float, Float, Float)
updateClockHands _ _ (s, m, h) = do
  currentTime <- realToFrac <$> getPOSIXTime
  let seconds = fromIntegral (mod (round currentTime) 60)
      minutes = fromIntegral (mod (round $ currentTime / 60) 60)
      hours = fromIntegral (mod (round $ currentTime / 3600) 12)
  return (seconds, minutes, hours)

-- Define beige color
beige :: Color
beige = makeColorI 245 245 220 255

-- Function to render the complete picture
render :: (Float, Float, Float) -> IO Picture
render (seconds, minutes, hours) =
  return $ Pictures
    [ Color beige $ ThickCircle 100 5
    , clockOuter
    , number12
    , number1
    , number2
    , number3
    , number4
    , number5
    , number6
    , number7
    , number8
    , number9
    , number10
    , number11
    , drawClockHands seconds minutes hours
    ]

main :: IO ()
main = simulateIO window beige 60 (0, 0, 0) render updateClockHands